@@ -1,13 +1,11 @@
+package Dist::Zilla::Plugin::InstallRelease;
 use strict;
 use warnings;
-
-package Dist::Zilla::Plugin::InstallRelease;
-BEGIN {
-  $Dist::Zilla::Plugin::InstallRelease::VERSION = '0.006';
-}
 # ABSTRACT: installs your dist after releasing
+our $VERSION = '0.007'; # VERSION
 
 use Carp ();
+use autodie;
 use Moose;
 with 'Dist::Zilla::Role::Plugin';
 with 'Dist::Zilla::Role::AfterRelease';
@@ -16,43 +14,45 @@ with 'Dist::Zilla::Role::AfterRelease';
 has install_command => (
     is      => 'ro',
     isa     => 'Str',
+    predicate => 'has_install_command',
 );
 
-
 sub after_release {
     my $self = shift;
 
-    my $return = eval {
+    eval {
         require File::pushd;
-        my $built_in = $self->zilla->built_in;
-        ## no critic Punctuation
-        my $wd = File::pushd::pushd($built_in);
-        my @cmd = $self->{install_command}
-                    ? split(/ /, $self->{install_command})
-                    : ($^X => '-MCPAN' =>
-                            $^O eq 'MSWin32' ? q{-e"install '.'"} : q{-einstall "."});
-
-        $self->log_debug([ 'installing via %s', \@cmd ]);
-        system(@cmd) && $self->log_fatal([ 'Error running %s', \@cmd ]);
+        my $wd = File::pushd::pushd($self->zilla->built_in);
+        if ($self->has_install_command) {
+            system($self->install_command)
+                && $self->log_fatal([ 'error running %s', [$self->install_command] ]);
+        }
+        else {
+            my @cmd = ($^X, '-MCPAN',
+                $^O eq 'MSWin32' ? q(-e"install '.'") : q(-einstall '.')
+            );
+            system(@cmd) && $self->log_fatal([ 'error running %s', \@cmd ]);
+        }
     };
 
     if ($@) {
-        $self->log("Install failed: $@");
-    }
-    elsif ($return == 0) {
-        $self->log("Install OK: $return");
+        $self->log($@);
+        $self->log('Install failed.');
     }
     else {
-        $self->log("Installed failed: $return");
+        $self->log('Install OK');
     }
+
     return;
 }
+
+
+__PACKAGE__->meta->make_immutable;
 no Moose;
 
 1;
 
-
-
+__END__
 =pod
 
 =encoding utf-8
@@ -63,7 +63,7 @@ Dist::Zilla::Plugin::InstallRelease - installs your dist after releasing
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 DESCRIPTION
 
@@ -80,15 +80,12 @@ You can specify an alternate install command:
     [InstallRelease]
     install_command = cpanm .
 
-=head1 METHODS
-
-=head2 after_release
-
-This gets called after the release is completed - it installs the built dist
-using L<CPAN> (unless you specified something different).
+=for Pod::Coverage after_release
 
 =head1 AVAILABILITY
 
+The project homepage is L<http://p3rl.org/Dist::Zilla::Plugin::InstallRelease>.
+
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see L<http://search.cpan.org/dist/Dist-Zilla-Plugin-InstallRelease/>.
@@ -98,12 +95,17 @@ and may be cloned from L<git://github.com/doherty/Dist-Zilla-Plugin-InstallRelea
 Instead of sending patches, please fork this project using the standard
 git and github infrastructure.
 
+=head1 SOURCE
+
+The development version is on github at L<http://github.com/doherty/Dist-Zilla-Plugin-InstallRelease>
+and may be cloned from L<git://github.com/doherty/Dist-Zilla-Plugin-InstallRelease.git>
+
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://github.com/doherty/Dist-Zilla-Plugin-InstallRelease/issues>.
+L<https://github.com/doherty/Dist-Zilla-Plugin-InstallRelease/issues>.
 
 =head1 AUTHOR
 
@@ -118,5 +120,3 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
-__END__
